pysis package
=============

Subpackages
-----------

.. toctree::

    pysis.binning
    pysis.labels
    pysis.util

Submodules
----------

pysis.cubefile module
---------------------

.. automodule:: pysis.cubefile
    :members:
    :undoc-members:
    :show-inheritance:

pysis.env module
----------------

.. automodule:: pysis.env
    :members:
    :undoc-members:
    :show-inheritance:

pysis.exceptions module
-----------------------

.. automodule:: pysis.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

pysis.isis module
-----------------

.. automodule:: pysis.isis
    :members:
    :undoc-members:
    :show-inheritance:

pysis.isiscommand module
------------------------

.. automodule:: pysis.isiscommand
    :members:
    :undoc-members:
    :show-inheritance:

pysis.isispool module
---------------------

.. automodule:: pysis.isispool
    :members:
    :undoc-members:
    :show-inheritance:

pysis.specialpixels module
--------------------------

.. automodule:: pysis.specialpixels
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pysis
    :members:
    :undoc-members:
    :show-inheritance:
